PyXMake Developer Guide: PyXMake.Plugin.__build Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.Plugin.__build Namespace Reference

## Functions
| build (*args, **kwargs)

## Variables
bool | exclude_source_files = wc and wc.exclude_source_files
bool | bdist_wheel = True
int | force = 1
int | compile = 1
| python_tag = None
bool | platform_tag = False
bool | root_is_pure = True

## Detailed Description

    Build configuration and management assistance wrapper.

    @note:
    Created on 03.02.2024

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-SY,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ build()

PyXMake.Plugin.__build.build | ( | * | args,
|  | ** | kwargs )

    Shim interface for python wheel setup

Definition at line 28 of file __build.py.

## Variable Documentation

## ◆ bdist_wheel

bool PyXMake.Plugin.__build.bdist_wheel = True

Definition at line 52 of file __build.py.

## ◆ compile

int PyXMake.Plugin.__build.compile = 1

Definition at line 64 of file __build.py.

## ◆ exclude_source_files

list PyXMake.Plugin.__build.exclude_source_files = wc and wc.exclude_source_files

Definition at line 51 of file __build.py.

## ◆ force

int PyXMake.Plugin.__build.force = 1

Definition at line 63 of file __build.py.

## ◆ platform_tag

PyXMake.Plugin.__build.platform_tag = False

Definition at line 114 of file __build.py.

## ◆ python_tag

PyXMake.Plugin.__build.python_tag = None

Definition at line 112 of file __build.py.

## ◆ root_is_pure

bool PyXMake.Plugin.__build.root_is_pure = True

Definition at line 125 of file __build.py.